pub enum DummyError {
OverContracted(Symbol),
BadContraction(Symbol),
}Expand description
Errors from dummy-index operations.
Variants
OverContracted(Symbol)
An index label appeared more than twice in a tensor product.
BadContraction(Symbol)
Two slots with the same label have the same variance (not an upper/lower pair).