SymmetrySpec

Struct SymmetrySpec 

pub struct SymmetrySpec {
    pub symmetric_subsets: Vec<Vec<usize>>,
    pub antisymmetric_subsets: Vec<Vec<usize>>,
    pub cyclic: Option<Vec<usize>>,
}
Slot symmetry for a tensor: a set of slot-index subsets that are symmetric, antisymmetric, or form a cycle.

Fields

symmetric_subsets: Vec<Vec<usize>>

Slot subsets whose members are interchangeable (symmetric).

antisymmetric_subsets: Vec<Vec<usize>>

Slot subsets whose members are antisymmetric (swap flips sign).

cyclic: Option<Vec<usize>>

Cyclic permutation on a subset of slots.

Implementations

Source

impl SymmetrySpec

pub fn none() -> Self

No symmetry at all — every slot is independent.

pub fn fully_symmetric(rank: usize) -> Self

All slots are fully symmetric.

pub fn fully_antisymmetric(rank: usize) -> Self

All slots are fully antisymmetric.

pub fn is_slot_hidden(&self, pos: usize) -> bool

Check whether this spec implies the given slot position should have its location “hidden” in the graph encoding (i.e. not participate in canonicalisation comparison).