pub struct Tensor<'a> { /* private fields */ }Expand description
A tensor: a named object with a list of index slots, an arity, and a slot symmetry.
Implementations
Sourceimpl<'a> Tensor<'a>
impl<'a> Tensor<'a>
Sourcepub fn new(name: Symbol, slots: Vec<IndexSlot<'a>>) -> Self
pub fn new(name: Symbol, slots: Vec<IndexSlot<'a>>) -> Self
Create a new tensor with the given slots and no symmetry.
Sourcepub fn with_symmetry(self, symmetry: Symmetry) -> Self
pub fn with_symmetry(self, symmetry: Symmetry) -> Self
Builder: set the slot symmetry.
Sourcepub fn dummy_labels(&self) -> Vec<Atom<'a>>
pub fn dummy_labels(&self) -> Vec<Atom<'a>>
Return the dummy indices (labels occurring exactly twice across all slots, once upper and once lower) — these are the ones that will be contracted in a product.